@@ -1,4 +1,4 @@
-from jms_utils.logging import format_string
+from jms_utils.logger import log_format_string
 from jms_utils.paths import ChDir
 from jms_utils.system import get_system
 from jms_utils.terminal import (get_terminal_size,
